@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,6 +32,9 @@
 #include <tracker-sparql.h>
 
 #include "photos-base-item.h"
+#include "photos-collection-icon-watcher.h"
+#include "photos-delete-item-job.h"
+#include "photos-print-operation.h"
 #include "photos-query.h"
 #include "photos-single-item-job.h"
 #include "photos-utils.h"
@@ -41,6 +44,11 @@ struct _PhotosBaseItemPrivate
 {
   GdkPixbuf *icon;
   GdkPixbuf *pristine_icon;
+  GeglNode *graph;
+  GeglNode *node;
+  GeglRectangle bbox;
+  GMutex mutex;
+  PhotosCollectionIconWatcher *watcher;
   TrackerSparqlCursor *cursor;
   gboolean collection;
   gboolean failed_thumbnailing;
@@ -165,7 +173,7 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
               icon = tmp;
             }
 
-          gtk_icon_info_free (icon_info);
+          g_object_unref (icon_info);
         }
     }
 
@@ -192,25 +200,36 @@ photos_base_item_check_effects_and_update_info (PhotosBaseItem *self)
 }
 
 
-static GdkPixbuf *
+static GeglNode *
 photos_base_item_default_load (PhotosBaseItem *self, GCancellable *cancellable, GError **error)
 {
   PhotosBaseItemPrivate *priv = self->priv;
-  GdkPixbuf *pixbuf = NULL;
+  GeglNode *ret_val = NULL;
   GFile *file = NULL;
-  GFileInputStream *stream = NULL;
+  gchar *path = NULL;
 
-  file = g_file_new_for_uri (priv->uri);
-  stream = g_file_read (file, cancellable, error);
-  if (stream == NULL)
-    goto out;
+  if (priv->graph == NULL)
+    {
+      file = g_file_new_for_uri (priv->uri);
+      path = g_file_get_path (file);
+      if (path == NULL)
+        goto out;
 
-  pixbuf = gdk_pixbuf_new_from_stream (G_INPUT_STREAM (stream), cancellable, error);
+      priv->graph = gegl_node_new ();
+      priv->node = gegl_node_new_child (priv->graph,
+                                        "operation", "gegl:load",
+                                        "path", path,
+                                        NULL);
+    }
+
+  gegl_node_process (priv->node);
+  priv->bbox = gegl_node_get_bounding_box (priv->node);
+  ret_val = g_object_ref (priv->node);
 
  out:
-  g_clear_object (&stream);
+  g_free (path);
   g_clear_object (&file);
-  return pixbuf;
+  return ret_val;
 }
 
 
@@ -221,6 +240,35 @@ photos_base_item_default_set_favorite (PhotosBaseItem *self, gboolean favorite)
 }
 
 
+static void
+photos_base_item_icon_updated (PhotosBaseItem *self, GIcon *icon)
+{
+  PhotosBaseItemPrivate *priv = self->priv;
+
+  if (icon == NULL)
+    return;
+
+  g_clear_object (&priv->icon);
+  priv->icon = g_object_ref (icon);
+  photos_base_item_check_effects_and_update_info (self);
+}
+
+
+static void
+photos_base_item_refresh_collection_icon (PhotosBaseItem *self)
+{
+  PhotosBaseItemPrivate *priv = self->priv;
+
+  if (priv->watcher == NULL)
+    {
+      priv->watcher = photos_collection_icon_watcher_new (self);
+      g_signal_connect_swapped (priv->watcher, "icon-updated", G_CALLBACK (photos_base_item_icon_updated), self);
+    }
+  else
+    photos_collection_icon_watcher_refresh (priv->watcher);
+}
+
+
 static void
 photos_base_item_refresh_executed (TrackerSparqlCursor *cursor, gpointer user_data)
 {
@@ -406,14 +454,19 @@ static void
 photos_base_item_load_in_thread_func (GSimpleAsyncResult *simple, GObject *object, GCancellable *cancellable)
 {
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (object);
-  GdkPixbuf *pixbuf;
+  PhotosBaseItemPrivate *priv = self->priv;
+  GeglNode *node;
   GError *error = NULL;
 
-  pixbuf = PHOTOS_BASE_ITEM_GET_CLASS (self)->load (self, cancellable, &error);
+  g_mutex_lock (&priv->mutex);
+
+  node = PHOTOS_BASE_ITEM_GET_CLASS (self)->load (self, cancellable, &error);
   if (error != NULL)
     g_simple_async_result_take_error (simple, error);
 
-  g_simple_async_result_set_op_res_gpointer (simple, (gpointer) pixbuf, g_object_unref);
+  g_simple_async_result_set_op_res_gpointer (simple, (gpointer) node, g_object_unref);
+
+  g_mutex_unlock (&priv->mutex);
 }
 
 
@@ -429,7 +482,8 @@ photos_base_item_update_icon_from_type (PhotosBaseItem *self)
   if (priv->mime_type != NULL)
     icon = g_content_type_get_icon (priv->mime_type);
 
-  /* TODO: Get icon from RDF type */
+  if (icon == NULL)
+    icon = photos_utils_icon_from_rdf_type (priv->rdf_type);
 
   theme = gtk_icon_theme_get_default ();
   icon_size = photos_utils_get_icon_size ();
@@ -461,6 +515,12 @@ photos_base_item_refresh_icon (PhotosBaseItem *self)
 
   photos_base_item_update_icon_from_type (self);
 
+  if (priv->collection)
+    {
+      photos_base_item_refresh_collection_icon (self);
+      return;
+    }
+
   if (priv->failed_thumbnailing)
     return;
 
@@ -541,6 +601,27 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
 }
 
 
+static void
+photos_base_item_print_load (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  PhotosBaseItem *self = PHOTOS_BASE_ITEM (source_object);
+  GtkWindow *toplevel = GTK_WINDOW (user_data);
+  GeglNode *node;
+  GtkPrintOperation *print_op;
+
+  node = photos_base_item_load_finish (self, res, NULL);
+  if (node == NULL)
+    goto out;
+
+  print_op = photos_print_operation_new (self, node);
+  gtk_print_operation_run (print_op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, toplevel, NULL);
+
+ out:
+  g_clear_object (&node);
+  g_object_unref (toplevel);
+}
+
+
 static void
 photos_base_item_update_type_description (PhotosBaseItem *self)
 {
@@ -572,8 +653,10 @@ photos_base_item_dispose (GObject *object)
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (object);
   PhotosBaseItemPrivate *priv = self->priv;
 
+  g_clear_object (&priv->graph);
   g_clear_object (&priv->icon);
   g_clear_object (&priv->pristine_icon);
+  g_clear_object (&priv->watcher);
   g_clear_object (&priv->cursor);
 
   G_OBJECT_CLASS (photos_base_item_parent_class)->dispose (object);
@@ -597,6 +680,8 @@ photos_base_item_finalize (GObject *object)
   g_free (priv->type_description);
   g_free (priv->uri);
 
+  g_mutex_clear (&priv->mutex);
+
   G_OBJECT_CLASS (photos_base_item_parent_class)->finalize (object);
 }
 
@@ -653,6 +738,8 @@ photos_base_item_init (PhotosBaseItem *self)
 
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, PHOTOS_TYPE_BASE_ITEM, PhotosBaseItemPrivate);
   priv = self->priv;
+
+  g_mutex_init (&priv->mutex);
 }
 
 
@@ -727,7 +814,8 @@ photos_base_item_can_trash (PhotosBaseItem *self)
 void
 photos_base_item_destroy (PhotosBaseItem *self)
 {
-  /* TODO: collection icon watcher, SearchCategoryManager */
+  /* TODO: SearchCategoryManager */
+  g_clear_object (&self->priv->watcher);
 }
 
 
@@ -738,6 +826,13 @@ photos_base_item_get_author (PhotosBaseItem *self)
 }
 
 
+GeglRectangle
+photos_base_item_get_bbox (PhotosBaseItem *self)
+{
+  return self->priv->bbox;
+}
+
+
 gint64
 photos_base_item_get_date_created (PhotosBaseItem *self)
 {
@@ -766,6 +861,13 @@ photos_base_item_get_id (PhotosBaseItem *self)
 }
 
 
+const gchar *
+photos_base_item_get_identifier (PhotosBaseItem *self)
+{
+  return self->priv->identifier;
+}
+
+
 const gchar *
 photos_base_item_get_mime_type (PhotosBaseItem *self)
 {
@@ -787,6 +889,20 @@ photos_base_item_get_name (PhotosBaseItem *self)
 }
 
 
+GdkPixbuf *
+photos_base_item_get_pristine_icon (PhotosBaseItem *self)
+{
+  return self->priv->pristine_icon;
+}
+
+
+const gchar *
+photos_base_item_get_resource_urn (PhotosBaseItem *self)
+{
+  return self->priv->resource_urn;
+}
+
+
 const gchar *
 photos_base_item_get_type_description (PhotosBaseItem *self)
 {
@@ -854,11 +970,11 @@ photos_base_item_load_async (PhotosBaseItem *self,
 }
 
 
-GdkPixbuf *
+GeglNode *
 photos_base_item_load_finish (PhotosBaseItem *self, GAsyncResult *res, GError **error)
 {
   GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (res);
-  GdkPixbuf *ret_val = NULL;
+  GeglNode *ret_val = NULL;
 
   g_return_val_if_fail (g_simple_async_result_is_valid (res, G_OBJECT (self), photos_base_item_load_async), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
@@ -866,7 +982,7 @@ photos_base_item_load_finish (PhotosBaseItem *self, GAsyncResult *res, GError **
   if (g_simple_async_result_propagate_error (simple, error))
     goto out;
 
-  ret_val = GDK_PIXBUF (g_simple_async_result_get_op_res_gpointer (simple));
+  ret_val = GEGL_NODE (g_simple_async_result_get_op_res_gpointer (simple));
   g_object_ref (ret_val);
 
  out:
@@ -893,6 +1009,7 @@ photos_base_item_open (PhotosBaseItem *self, GdkScreen *screen, guint32 timestam
 void
 photos_base_item_print (PhotosBaseItem *self, GtkWidget *toplevel)
 {
+  photos_base_item_load_async (self, NULL, photos_base_item_print_load, g_object_ref (toplevel));
 }
 
 
@@ -922,3 +1039,18 @@ photos_base_item_set_favorite (PhotosBaseItem *self, gboolean favorite)
 {
   PHOTOS_BASE_ITEM_GET_CLASS (self)->set_favorite (self, favorite);
 }
+
+
+void
+photos_base_item_trash (PhotosBaseItem *self)
+{
+  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosDeleteItemJob *job;
+
+  if (!priv->collection)
+    return;
+
+  job = photos_delete_item_job_new (priv->id);
+  photos_delete_item_job_run (job, NULL, NULL);
+  g_object_unref (job);
+}
