@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -202,6 +202,7 @@ photos_properties_dialog_constructed (GObject *object)
       priv->title_entry = gtk_entry_new ();
       gtk_widget_set_halign (priv->title_entry, GTK_ALIGN_START);
       gtk_widget_set_hexpand (priv->title_entry, TRUE);
+      gtk_entry_set_activates_default (GTK_ENTRY (priv->title_entry), TRUE);
       gtk_entry_set_text (GTK_ENTRY (priv->title_entry), name);
       gtk_editable_set_editable (GTK_EDITABLE (priv->title_entry), TRUE);
 
@@ -243,6 +244,9 @@ photos_properties_dialog_constructed (GObject *object)
 
       source_data = gtk_link_button_new_with_label (source_uri, source_path);
       gtk_widget_set_halign (source_data, GTK_ALIGN_START);
+
+      g_object_unref (source_link);
+      g_object_unref (file);
     }
 
   gtk_grid_attach_next_to (GTK_GRID (grid), source_data, source, 1, 2, 1);
@@ -264,8 +268,6 @@ photos_properties_dialog_constructed (GObject *object)
   item_type_data = gtk_label_new (type_description);
   gtk_widget_set_halign (item_type_data, GTK_ALIGN_START);
   gtk_grid_attach_next_to (GTK_GRID (grid), item_type_data, item_type, 1, 2, 1);
-
-  gtk_widget_show_all (GTK_WIDGET (self));
 }
 
 
@@ -326,6 +328,7 @@ photos_properties_dialog_init (PhotosPropertiesDialog *self)
 
   priv->item_mngr = photos_item_manager_new ();
   gtk_dialog_add_button (GTK_DIALOG (self), _("Done"), GTK_RESPONSE_OK);
+  gtk_dialog_set_default_response (GTK_DIALOG (self), GTK_RESPONSE_OK);
 }
 
 
