@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,9 +27,12 @@
 
 #include <gio/gio.h>
 
+#include "photos-collection-manager.h"
+#include "photos-offset-collections-controller.h"
 #include "photos-offset-favorites-controller.h"
 #include "photos-offset-overview-controller.h"
 #include "photos-query-builder.h"
+#include "photos-search-type.h"
 #include "photos-source-manager.h"
 #include "photos-search-type-manager.h"
 
@@ -51,8 +54,26 @@ photos_query_builder_convert_path_to_uri (const gchar *path)
 }
 
 
+static void
+photos_query_builder_set_search_type (gint flags)
+{
+  PhotosBaseManager *srch_typ_mngr;
+
+  srch_typ_mngr = photos_search_type_manager_new ();
+
+  if (flags & PHOTOS_QUERY_FLAGS_COLLECTIONS)
+    photos_base_manager_set_active_object_by_id (srch_typ_mngr, PHOTOS_SEARCH_TYPE_STOCK_COLLECTIONS);
+  else if (flags & PHOTOS_QUERY_FLAGS_FAVORITES)
+    photos_base_manager_set_active_object_by_id (srch_typ_mngr, PHOTOS_SEARCH_TYPE_STOCK_FAVORITES);
+  else
+    photos_base_manager_set_active_object_by_id (srch_typ_mngr, PHOTOS_SEARCH_TYPE_STOCK_ALL);
+
+  g_object_unref (srch_typ_mngr);
+}
+
+
 static gchar *
-photos_query_builder_filter (void)
+photos_query_builder_filter (gint flags)
 {
   PhotosBaseManager *src_mngr;
   PhotosBaseManager *srch_typ_mngr;
@@ -64,10 +85,12 @@ photos_query_builder_filter (void)
   src_mngr_filter = photos_base_manager_get_filter (src_mngr);
 
   srch_typ_mngr = photos_search_type_manager_new ();
+  photos_query_builder_set_search_type (flags);
   srch_typ_mngr_filter = photos_base_manager_get_filter (srch_typ_mngr);
 
   sparql = g_strdup_printf ("FILTER (%s && %s)", src_mngr_filter, srch_typ_mngr_filter);
 
+  photos_query_builder_set_search_type (PHOTOS_QUERY_FLAGS_NONE);
   g_free (srch_typ_mngr_filter);
   g_object_unref (srch_typ_mngr);
 
@@ -86,6 +109,54 @@ photos_query_builder_optional (void)
 }
 
 
+static gchar *
+photos_query_builder_where (gboolean global, gint flags)
+{
+  PhotosBaseManager *col_mngr;
+  PhotosBaseManager *srch_typ_mngr;
+  gchar *col_mngr_where = NULL;
+  gchar *filter = NULL;
+  gchar *optional = NULL;
+  gchar *sparql;
+  gchar *srch_typ_mngr_where = NULL;
+
+  col_mngr = photos_collection_manager_new ();
+
+  srch_typ_mngr = photos_search_type_manager_new ();
+  photos_query_builder_set_search_type (flags);
+  srch_typ_mngr_where = photos_search_type_manager_get_where (PHOTOS_SEARCH_TYPE_MANAGER (srch_typ_mngr));
+
+  optional = photos_query_builder_optional ();
+
+  if (!(flags & PHOTOS_QUERY_FLAGS_UNFILTERED))
+    {
+      if (global)
+        {
+          /* TODO: SearchCategoryManager */
+
+          col_mngr_where = photos_collection_manager_get_where (PHOTOS_COLLECTION_MANAGER (col_mngr));
+        }
+
+      filter = photos_query_builder_filter (flags);
+    }
+
+  sparql = g_strdup_printf ("WHERE { %s %s %s %s }",
+                            srch_typ_mngr_where,
+                            optional,
+                            (col_mngr_where != NULL) ? col_mngr_where : "",
+                            (filter != NULL) ? filter : "");
+
+  photos_query_builder_set_search_type (PHOTOS_QUERY_FLAGS_NONE);
+  g_free (col_mngr_where);
+  g_free (filter);
+  g_free (srch_typ_mngr_where);
+  g_object_unref (col_mngr);
+  g_object_unref (srch_typ_mngr);
+
+  return sparql;
+}
+
+
 static gchar *
 photos_query_builder_query (gboolean global, gint flags)
 {
@@ -96,30 +167,7 @@ photos_query_builder_query (gboolean global, gint flags)
   gchar *tmp;
   gchar *where_sparql;
 
-  optional = photos_query_builder_optional ();
-  if (flags & PHOTOS_QUERY_FLAGS_FAVORITES)
-    where_sparql = g_strconcat ("WHERE { ?urn nao:hasTag nao:predefined-tag-favorite ", optional, NULL);
-  else
-    where_sparql = g_strconcat ("WHERE { ?urn a rdfs:Resource ", optional, NULL);
-  g_free (optional);
-
-  if (!(flags & PHOTOS_QUERY_FLAGS_UNFILTERED))
-    {
-      if (global)
-        {
-          /* TODO: CollectionManager, etc.. */
-        }
-
-      filter = photos_query_builder_filter ();
-      tmp = where_sparql;
-      where_sparql = g_strconcat (where_sparql, filter, NULL);
-      g_free (tmp);
-      g_free (filter);
-    }
-
-  tmp = where_sparql;
-  where_sparql = g_strconcat (where_sparql, " }", NULL);
-  g_free (tmp);
+  where_sparql = photos_query_builder_where (global, flags);
 
   if (global)
     {
@@ -127,7 +175,9 @@ photos_query_builder_query (gboolean global, gint flags)
       gint offset;
       gint step;
 
-      if (flags & PHOTOS_QUERY_FLAGS_FAVORITES)
+      if (flags & PHOTOS_QUERY_FLAGS_COLLECTIONS)
+        offset_cntrlr = photos_offset_collections_controller_new ();
+      else if (flags & PHOTOS_QUERY_FLAGS_FAVORITES)
         offset_cntrlr = photos_offset_favorites_controller_new ();
       else
         offset_cntrlr = photos_offset_overview_controller_new ();
@@ -157,65 +207,106 @@ photos_query_builder_query (gboolean global, gint flags)
                         NULL);
   g_free (where_sparql);
   g_free (tail_sparql);
+
   return sparql;
 }
 
 
 PhotosQuery *
-photos_query_builder_count_favorites_query (void)
+photos_query_builder_create_collection_query (const gchar *name)
 {
-  gchar *filter;
-  gchar *optional;
+  GTimeVal tv;
   gchar *sparql;
+  gchar *time;
+  gint64 timestamp;
 
-  filter = photos_query_builder_filter ();
-  optional = photos_query_builder_optional ();
-  sparql = g_strconcat ("SELECT DISTINCT COUNT(?urn) WHERE { ?urn nao:hasTag nao:predefined-tag-favorite ",
-                        optional,
-                        filter,
-                        " }", NULL);
+  timestamp = g_get_real_time () / G_USEC_PER_SEC;
+  tv.tv_sec = timestamp;
+  tv.tv_usec = 0;
+  time = g_time_val_to_iso8601 (&tv);
 
-  g_free (optional);
-  g_free (filter);
+  sparql = g_strdup_printf ("INSERT { _:res a nfo:DataContainer ; a nie:DataObject ; "
+                            "nie:contentLastModified '%s' ; "
+                            "nie:title '%s' ; "
+                            "nao:identifier '%s%s' }",
+                            time,
+                            name,
+                            PHOTOS_QUERY_LOCAL_COLLECTIONS_IDENTIFIER,
+                            name);
+  g_free (time);
 
   return photos_query_new (sparql);
 }
 
 
 PhotosQuery *
-photos_query_builder_count_query (void)
+photos_query_builder_collection_icon_query (const gchar *resource)
 {
-  gchar *filter;
-  gchar *optional;
   gchar *sparql;
 
-  filter = photos_query_builder_filter ();
-  optional = photos_query_builder_optional ();
-  sparql = g_strconcat ("SELECT DISTINCT COUNT(?urn) WHERE { ?urn a rdfs:Resource ", optional, filter, " }", NULL);
+  sparql = g_strdup_printf ("SELECT ?urn "
+                            "tracker:coalesce(nfo:fileLastModified(?urn), nie:contentLastModified(?urn)) AS ?mtime "
+                            "WHERE { ?urn nie:isPartOf <%s> } "
+                            "ORDER BY DESC (?mtime) LIMIT 4",
+                            resource);
+  return photos_query_new (sparql);
+}
 
-  g_free (optional);
-  g_free (filter);
+
+PhotosQuery *
+photos_query_builder_count_query (gint flags)
+{
+  PhotosBaseManager *srch_typ_mngr;
+  gchar *sparql;
+  gchar *where_sparql;
+
+  where_sparql = photos_query_builder_where (TRUE, flags);
+  sparql = g_strconcat ("SELECT DISTINCT COUNT(?urn) ", where_sparql, NULL);
+  g_free (where_sparql);
 
   return photos_query_new (sparql);
 }
 
 
 PhotosQuery *
-photos_query_builder_global_favorites_query (void)
+photos_query_builder_delete_resource_query (const gchar *resource)
 {
   gchar *sparql;
 
-  sparql = photos_query_builder_query (TRUE, PHOTOS_QUERY_FLAGS_FAVORITES);
+  sparql = g_strdup_printf ("DELETE { <%s> a rdfs:Resource }", resource);
   return photos_query_new (sparql);
 }
 
 
 PhotosQuery *
-photos_query_builder_global_query (void)
+photos_query_builder_fetch_collections_query (const gchar *resource)
 {
   gchar *sparql;
 
-  sparql = photos_query_builder_query (TRUE, PHOTOS_QUERY_FLAGS_NONE);
+  sparql = g_strdup_printf ("SELECT ?urn WHERE { ?urn a nfo:DataContainer . <%s> nie:isPartOf ?urn }", resource);
+  return photos_query_new (sparql);
+}
+
+
+PhotosQuery *
+photos_query_builder_global_query (gint flags)
+{
+  gchar *sparql;
+
+  sparql = photos_query_builder_query (TRUE, flags);
+  return photos_query_new (sparql);
+}
+
+
+PhotosQuery *
+photos_query_builder_set_collection_query (const gchar *item_urn, const gchar *collection_urn, gboolean setting)
+{
+  gchar *sparql;
+
+  sparql = g_strdup_printf ("%s { <%s> nie:isPartOf <%s> }",
+                            setting ? "INSERT" : "DELETE",
+                            item_urn,
+                            collection_urn);
   return photos_query_new (sparql);
 }
 
@@ -241,6 +332,26 @@ photos_query_builder_single_query (gint flags, const gchar *resource)
 }
 
 
+PhotosQuery *
+photos_query_builder_update_mtime_query (const gchar *resource)
+{
+  GTimeVal tv;
+  gchar *sparql;
+  gchar *time;
+  gint64 timestamp;
+
+  timestamp = g_get_real_time () / G_USEC_PER_SEC;
+  tv.tv_sec = timestamp;
+  tv.tv_usec = 0;
+  time = g_time_val_to_iso8601 (&tv);
+
+  sparql = g_strdup_printf ("INSERT OR REPLACE { <%s> nie:contentLastModified \"%s\" }", resource, time);
+  g_free (time);
+
+  return photos_query_new (sparql);
+}
+
+
 gchar *
 photos_query_builder_filter_local (void)
 {
@@ -260,12 +371,14 @@ photos_query_builder_filter_local (void)
   path = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
   pictures_uri = photos_query_builder_convert_path_to_uri (path);
 
-  filter = g_strdup_printf ("((fn:contains (nie:url (?urn), \"%s\"))"
-                            " || (fn:contains (nie:url (?urn), \"%s\"))"
-                            " || (fn:contains (nie:url (?urn), \"%s\")))",
+  filter = g_strdup_printf ("(fn:contains (nie:url (?urn), \"%s\")"
+                            " || fn:contains (nie:url (?urn), \"%s\")"
+                            " || fn:contains (nie:url (?urn), \"%s\")"
+                            " || fn:starts-with (nao:identifier (?urn), \"%s\"))",
                             desktop_uri,
                             download_uri,
-                            pictures_uri);
+                            pictures_uri,
+                            PHOTOS_QUERY_LOCAL_COLLECTIONS_IDENTIFIER);
   g_free (desktop_uri);
   g_free (download_uri);
   g_free (pictures_uri);
