@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,10 @@
 #include "photos-source-manager.h"
 
 
+const gchar *PHOTOS_QUERY_COLLECTIONS_IDENTIFIER = "photos:collection:";
+const gchar *PHOTOS_QUERY_LOCAL_COLLECTIONS_IDENTIFIER = "photos:collection:local:";
+
+
 PhotosQuery *
 photos_query_new (gchar *sparql)
 {
