@@ -46,16 +46,11 @@ static void
 photos_source_manager_client_account_added (GoaClient *client, GoaObject *object, gpointer user_data)
 {
   PhotosSourceManager *self = PHOTOS_SOURCE_MANAGER (user_data);
-  photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (object));
-}
+  PhotosSource *source;
 
-
-static void
-photos_source_manager_client_account_changed (GoaClient *client, GoaObject *object, gpointer user_data)
-{
-  PhotosSourceManager *self = PHOTOS_SOURCE_MANAGER (user_data);
-  photos_base_manager_remove_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (object));
-  photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (object));
+  source = photos_source_new_from_goa_object (object);
+  photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (source));
+  g_object_unref (source);
 }
 
 
@@ -63,7 +58,21 @@ static void
 photos_source_manager_client_account_removed (GoaClient *client, GoaObject *object, gpointer user_data)
 {
   PhotosSourceManager *self = PHOTOS_SOURCE_MANAGER (user_data);
-  photos_base_manager_remove_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (object));
+  GoaAccount *account;
+  const gchar *id;
+
+  account = goa_object_peek_account (object);
+  id = goa_account_get_id (account);
+  photos_base_manager_remove_object_by_id (PHOTOS_BASE_MANAGER (self), id);
+}
+
+
+static void
+photos_source_manager_client_account_changed (GoaClient *client, GoaObject *object, gpointer user_data)
+{
+  PhotosSourceManager *self = PHOTOS_SOURCE_MANAGER (user_data);
+  photos_source_manager_client_account_removed (client, object, user_data);
+  photos_source_manager_client_account_added (client, object, user_data);
 }
 
 
@@ -77,11 +86,15 @@ photos_source_manager_refresh_accounts (PhotosSourceManager *self)
   accounts = goa_client_get_accounts (priv->client);
   for (l = accounts; l != NULL; l = l->next)
     {
+      PhotosSource *source;
+
       if (goa_object_peek_account (GOA_OBJECT (l->data)) == NULL)
         continue;
 
       /* TODO: uncomment when we start supporting online providers */
-      /* photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (l->data)); */
+      /* source = photos_source_new_from_goa_object (GOA_OBJECT (l->data)); */
+      /* photos_base_manager_add_object (PHOTOS_BASE_MANAGER (self), G_OBJECT (source)); */
+      /* g_object_unref (source); */
     }
 
   g_list_free_full (accounts, g_object_unref);
