@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,11 +41,111 @@
 static const gchar *dot_dir;
 
 
-void
-photos_utils_alpha_gtk_widget (GtkWidget *widget)
+GIcon *
+photos_utils_create_collection_icon (gint base_size, GList *pixbufs)
 {
-  GdkRGBA color = {0.0, 0.0, 0.0, 0.0};
-  gtk_widget_override_background_color (widget, GTK_STATE_FLAG_NORMAL, &color);
+  cairo_surface_t *surface;
+  cairo_t *cr;
+  GdkPixbuf *pix;
+  GIcon *ret_val;
+  GList *l;
+  GtkStyleContext *context;
+  GtkWidgetPath *path;
+  gint cur_x;
+  gint cur_y;
+  gint idx;
+  gint padding;
+  gint pix_height;
+  gint pix_width;
+  gint scale_size;
+  gint tile_size;
+
+  /* TODO: do not hardcode 4, but scale to another layout if more
+   * pixbufs are provided.
+   */
+
+  padding = MAX (floor (base_size / 10), 4);
+  tile_size = (base_size - (3 * padding)) / 2;
+
+  context = gtk_style_context_new ();
+  gtk_style_context_add_class (context, "documents-collection-icon");
+
+  path = gtk_widget_path_new ();
+  gtk_widget_path_append_type (path, GTK_TYPE_ICON_VIEW);
+  gtk_style_context_set_path (context, path);
+  gtk_widget_path_unref (path);
+
+  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, base_size, base_size);
+  cr = cairo_create (surface);
+
+  gtk_render_background (context, cr, 0, 0, base_size, base_size);
+
+  l = pixbufs;
+  idx = 0;
+  cur_x = padding;
+  cur_y = padding;
+
+  while (l != NULL && idx < 4)
+    {
+      pix = l->data;
+      pix_width = gdk_pixbuf_get_width (pix);
+      pix_height = gdk_pixbuf_get_height (pix);
+
+      scale_size = MIN (pix_width, pix_height);
+
+      cairo_save (cr);
+
+      cairo_translate (cr, cur_x, cur_y);
+
+      cairo_rectangle (cr, 0, 0,
+                       tile_size, tile_size);
+      cairo_clip (cr);
+
+      cairo_scale (cr, (gdouble) tile_size / (gdouble) scale_size, (gdouble) tile_size / (gdouble) scale_size);
+      gdk_cairo_set_source_pixbuf (cr, pix, 0, 0);
+
+      cairo_paint (cr);
+      cairo_restore (cr);
+
+      if ((idx % 2) == 0)
+        {
+          cur_x += tile_size + padding;
+        }
+      else
+        {
+          cur_x = padding;
+          cur_y += tile_size + padding;
+        }
+
+      idx++;
+      l = l->next;
+    }
+
+  ret_val = G_ICON (gdk_pixbuf_get_from_surface (surface, 0, 0, base_size, base_size));
+
+  cairo_surface_destroy (surface);
+  cairo_destroy (cr);
+  g_object_unref (context);
+
+  return ret_val;
+}
+
+
+GdkPixbuf *
+photos_utils_create_pixbuf_from_node (GeglNode *node)
+{
+  GdkPixbuf *pixbuf = NULL;
+  GeglNode *save_pixbuf;
+
+  save_pixbuf = gegl_node_new_child (gegl_node_get_parent (node),
+                                     "operation", "gegl:save-pixbuf",
+                                     "pixbuf", &pixbuf,
+                                     NULL);
+  gegl_node_link_many (node, save_pixbuf, NULL);
+  gegl_node_process (save_pixbuf);
+  g_object_unref (save_pixbuf);
+
+  return pixbuf;
 }
 
 
@@ -62,15 +162,14 @@ photos_utils_create_symbolic_icon (const gchar *name, gint base_size)
   cairo_surface_t *surface;
   cairo_t *cr;
   gchar *symbolic_name;
-  const gint bg_min_size = 20;
-  const gint emblem_min_size = 8;
-  gint bg_size;
+  const gint bg_size = 24;
+  const gint emblem_margin = 4;
+  gint emblem_pos;
   gint emblem_size;
   gint total_size;
 
   total_size = base_size / 2;
-  bg_size = MAX (total_size / 2, bg_min_size);
-  emblem_size = MAX (bg_size - 8, emblem_min_size);
+  emblem_size = bg_size - emblem_margin * 2;
 
   surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, total_size, total_size);
   cr = cairo_create (surface);
@@ -82,9 +181,9 @@ photos_utils_create_symbolic_icon (const gchar *name, gint base_size)
   gtk_style_context_set_path (style, path);
   gtk_widget_path_unref (path);
 
-  gtk_style_context_add_class (style, "documents-icon-bg");
+  gtk_style_context_add_class (style, "photos-icon-bg");
 
-  gtk_render_background (style, cr, (total_size - bg_size) / 2, (total_size - bg_size) / 2, bg_size, bg_size);
+  gtk_render_background (style, cr, total_size - bg_size, total_size - bg_size, bg_size, bg_size);
 
   symbolic_name = g_strconcat (name, "-symbolic", NULL);
   icon = g_themed_icon_new_with_default_fallbacks (symbolic_name);
@@ -98,12 +197,13 @@ photos_utils_create_symbolic_icon (const gchar *name, gint base_size)
     goto out;
 
   pixbuf = gtk_icon_info_load_symbolic_for_context (info, style, NULL, NULL);
-  gtk_icon_info_free (info);
+  g_object_unref (info);
 
   if (pixbuf == NULL)
     goto out;
 
-  gtk_render_icon (style, cr, pixbuf, (total_size - emblem_size) / 2,  (total_size - emblem_size) / 2);
+  emblem_pos = total_size - emblem_size - emblem_margin;
+  gtk_render_icon (style, cr, pixbuf, emblem_pos, emblem_pos);
   g_object_unref (pixbuf);
 
   ret_val = G_ICON (gdk_pixbuf_get_from_surface (surface, 0, 0, total_size, total_size));
@@ -498,6 +598,20 @@ photos_utils_get_urns_from_paths (GList *paths, GtkTreeModel *model)
 }
 
 
+GIcon *
+photos_utils_icon_from_rdf_type (const gchar *type)
+{
+  GIcon *ret_val = NULL;
+  gint size;
+
+  size = photos_utils_get_icon_size ();
+  if (strstr (type, "nfo#DataContainer") != NULL)
+    ret_val = photos_utils_create_collection_icon (size, NULL);
+
+  return ret_val;
+}
+
+
 void
 photos_utils_queue_thumbnail_job_for_file_async (GFile *file, GAsyncReadyCallback callback, gpointer user_data)
 {
