@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 Red Hat, Inc.
+ * Copyright © 2012, 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,13 +27,16 @@
 #define PHOTOS_UTILS_H
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gegl.h>
 #include <gio/gio.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-void             photos_utils_alpha_gtk_widget            (GtkWidget *widget);
+GIcon           *photos_utils_create_collection_icon      (gint base_size, GList *pixbufs);
+
+GdkPixbuf       *photos_utils_create_pixbuf_from_node     (GeglNode *node);
 
 GIcon           *photos_utils_create_symbolic_icon        (const gchar *name, gint base_size);
 
@@ -60,6 +63,8 @@ GtkBorder       *photos_utils_get_thumbnail_frame_border  (void);
 
 GList           *photos_utils_get_urns_from_paths         (GList *paths, GtkTreeModel *model);
 
+GIcon           *photos_utils_icon_from_rdf_type          (const gchar *type);
+
 void             photos_utils_queue_thumbnail_job_for_file_async (GFile *file,
                                                                   GAsyncReadyCallback callback,
                                                                   gpointer user_data);
